@@ -30,6 +30,3 @@ admin.site.register(User, UserAdmin)
 refs.register(Reference(name=_('Countries'), group=_('Geo'), url='enre/geo/views/CountryView'))
 refs.register(Reference(name=_('Regions'), group=_('Geo'), url='enre/geo/views/RegionView'))
 refs.register(Reference(name=_('Currencies'), group=_('Accounting'), url='enre/geo/views/CurrencyView'))
-
-for i in range(10):
-    refs.register(Reference(name='XZ Item' + str(i), group='XZ'))
