@@ -21,12 +21,12 @@ class UserService(ModelService):
             if obj['password'] != '_hidden_password_':
                 _passwd = obj['password']
             del obj['password']
-        pk = super(UserService, self).save(obj)
+        user = super(UserService, self).save(obj)
         if _passwd:
-            user = self.model.objects.get(pk=pk)
             user.set_password(_passwd)
             user.save()
-        return pk
+            user.password = '_hidden_password_'
+        return user
 
     @permissions_required(['delete_user'])
     def delete(self, pk):
