@@ -2,6 +2,8 @@ qx.Theme.define('enre.erp.theme.Color', {
     extend:enre.theme.simple.Color,
 
     colors:{
+        'background':'#F6F6F6',
+
         'menubar-link':'#24B',
         'moduletab-unselected':'#DCDCDC',
         'moduletab-button-border':'#000000',
@@ -15,6 +17,20 @@ qx.Theme.define('enre.erp.theme.Decoration', {
     extend:enre.theme.simple.Decoration,
 
     decorations:{
+
+        "white-box":{
+            decorator:[
+                qx.ui.decoration.MSingleBorder,
+                qx.ui.decoration.MBackgroundColor
+            ],
+
+            style:{
+                width:1,
+                color:"white-box-border",
+                backgroundColor:"white"
+            }
+        },
+
         'moduletab-border':{
             decorator:qx.ui.decoration.Uniform,
 
@@ -102,10 +118,92 @@ qx.Theme.define('enre.erp.theme.Appearance', {
 
     appearances:{
 
+        "table":{
+            style:function (states) {
+                return {
+                    backgroundColor:'white'
+                }
+            }
+        },
+
+
+        "groupbox":{},
+
+        "groupbox/legend":{
+            alias:"atom",
+
+            style:function (states) {
+                return {
+                    textColor:states.invalid ? "invalid" : undefined,
+                    padding:[0, 0, 0, 5],
+                    margin:0,
+                    font:"bold"
+                };
+            }
+        },
+
+
+        "groupbox/frame":{
+            style:function (states) {
+                return {
+                    backgroundColor:"background",
+                    padding:[6, 9],
+                    margin:[10, 0, 0, 0],
+                    decorator:"white-box"
+                };
+            }
+        },
+
+        "check-groupbox" : "groupbox",
+
+        "check-groupbox/legend" :
+        {
+            alias : "checkbox",
+            include : "checkbox",
+
+            style: function(states) {
+                return {
+                    textColor : states.invalid ? "invalid" : undefined,
+                    padding:[0, 0, 0, 5],
+                    font: "bold"
+                }
+            }
+        },
+
+        "menu" :
+        {
+            style : function(states)
+            {
+                var result =
+                {
+                    backgroundColor : "white",
+                    decorator : "main",
+                    spacingX : 6,
+                    spacingY : 1,
+                    iconColumnWidth : 16,
+                    arrowColumnWidth : 4,
+                    padding : 1,
+                    placementModeY : states.submenu || states.contextmenu ? "best-fit" : "keep-align"
+                };
+
+                if (states.submenu)
+                {
+                    result.position = "right-top";
+                    result.offset = [-2, -3];
+                }
+
+                if (states.contextmenu) {
+                    result.offset = 4;
+                }
+
+                return result;
+            }
+        },
+
         'appbar':{
             style:function (states) {
                 return {
-                    backgroundColor:'background',
+                    backgroundColor:'white',
                     padding:[2, 2]
                 };
             }
@@ -134,7 +232,15 @@ qx.Theme.define('enre.erp.theme.Appearance', {
             }
         },
 
-        'moduletab':'tabview',
+        'moduletab': {
+            alias: 'tabview',
+
+            style: function(states) {
+                return {
+                    backgroundColor: 'white'
+                }
+            }
+        },
 
         'moduletab/pane':{
             style:function (states) {
