@@ -15,12 +15,6 @@ qx.Class.define('enre.erp.party.views.PartyRoleWindow', {
         this.bindForm(form);
         this.addWidget(new enre.ui.form.SingleRenderer(form));
 
-    },
-
-    members: {
-        _initControls: function() {
-            this.base(arguments);
-        }
     }
 });
 
