@@ -49,13 +49,12 @@ qx.Class.define('enre.erp.party.views.PartyTypeView', {
     construct:function () {
         this.base(arguments, 'enre/erp/party/stores/PartyTypeStore',
                 [
-                    ['{% trans 'Code name' %}', '{% trans 'Name' %}', '{% trans 'Template' %}'],
-                    ['codename', 'name', 'template']
+                    ['{% trans 'Code name' %}', '{% trans 'Name' %}'],
+                    ['codename', 'name']
                 ],
                 'enre.erp.party.services.PartyTypeService',
                 enre.erp.party.views.PartyTypeWindow
         );
         this.setColumnWidth(0, '15%');
-        this.setColumnWidth(1, '50%');
     }
 });
